@@ -1,8 +1,8 @@
-var assetUrl = __admin_media_prefix__.replace('/admin/', '')
+var assetUrl = __admin_media_prefix__.replace('/admin/', '/') + 's3direct/js/'
 
-if( ! jQuery.widget) $.getScript(assetUrl + '/jquery.ui.widget.js')
-if( ! $.ajaxTransport) $.getScript(assetUrl + '/jquery.iframe-transport.js')
-if( ! jQuery().fileupload) $.getScript(assetUrl + '/jquery.fileupload.js')
+if( ! jQuery.widget) $.getScript(assetUrl + 'jquery.ui.widget.js')
+if( ! $.ajaxTransport) $.getScript(assetUrl + 'jquery.iframe-transport.js')
+if( ! jQuery().fileupload) $.getScript(assetUrl + 'jquery.fileupload.js')
 
 
 $(function(){
